==> haskell-crypto-numbers-0.2.7-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-8jbI9vZ2g8VFEPllUK8h2w
key: crypto-numbers-0.2.7-8jbI9vZ2g8VFEPllUK8h2w
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Number.ModArithmetic Crypto.Number.Serialize
    Crypto.Number.Generate Crypto.Number.Basic Crypto.Number.Polynomial
    Crypto.Number.F2m Crypto.Number.Prime
abi: efe4ff5ee1ac3038fec4b7c7a4058c8c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-8jbI9vZ2g8VFEPllUK8h2w
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    crypto-random-0.0.9-DWV3dcrdJbJH1ghEKFtuv9 ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-Gyqs6fz6gGAioSwtXuIUD
key: crypto-numbers-0.2.7-Gyqs6fz6gGAioSwtXuIUD
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Number.ModArithmetic Crypto.Number.Serialize
    Crypto.Number.Generate Crypto.Number.Basic Crypto.Number.Polynomial
    Crypto.Number.F2m Crypto.Number.Prime
abi: f1a96fbacceb10c4c88366247e17fe82
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-numbers-0.2.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-Gyqs6fz6gGAioSwtXuIUD
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    crypto-random-0.0.9-GFoLybqoqGJ8aoFMcvutKJ ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
